#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-EGYQdR2gSK4IsR7LLld6Sh
key:                  text-rope-0.3-EGYQdR2gSK4IsR7LLld6Sh
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  4e67a3d506d9eaaba0ec384224a29d39
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-rope-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-EGYQdR2gSK4IsR7LLld6Sh
depends:
    base-4.18.2.1 deepseq-1.4.8.1 text-2.0.2
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

